spharpy
=======

.. toctree::
   :maxdepth: 2

   intro


Documentation
=============

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules

Contributing
===============

.. toctree::
    :maxdepth: 2

    contributing

Other
=====
.. toctree::
    :maxdepth: 1

    authors
    history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
